@@ -15,6 +15,7 @@ from types    import SimpleNamespace
 
 from .argparse    import HelpFormatter, register_commands, register_default_command
 from .command     import build, view, deploy, remote, shell, update, check_setup, login, logout, whoami, version, debugger
+from .debug       import DEBUGGING
 from .errors      import NextstrainCliError
 from .util        import warn
 from .__version__ import __version__ # noqa: F401 (for re-export)
@@ -32,7 +33,10 @@ def run(args):
         return opts.__command__.run(opts)
 
     except NextstrainCliError as error:
-        warn(error)
+        if DEBUGGING:
+            traceback.print_exc()
+        else:
+            warn(error)
         return 1
 
     except AssertionError:
