@@ -41,6 +41,13 @@ def test_setup() -> RunnerTestResults:
     ]
 
 
+def set_default_config() -> None:
+    """
+    No-op.
+    """
+    pass
+
+
 def update() -> bool:
     """
     No-op.  Updating the native environment isn't reasonably possible.
