@@ -51,13 +51,13 @@ class RunnerModule(Protocol):
 
 class RemoteModule(Protocol):
     @staticmethod
-    def upload(url: urllib.parse.ParseResult, local_files: List[Path]) -> Iterable[Tuple[Path, str]]: ...
+    def upload(url: urllib.parse.ParseResult, local_files: List[Path], dry_run: bool = False) -> Iterable[Tuple[Path, str]]: ...
 
     @staticmethod
-    def download(url: urllib.parse.ParseResult, local_path: Path, recursively: bool = False) -> Iterable[Tuple[str, Path]]: ...
+    def download(url: urllib.parse.ParseResult, local_path: Path, recursively: bool = False, dry_run: bool = False) -> Iterable[Tuple[str, Path]]: ...
 
     @staticmethod
     def ls(url: urllib.parse.ParseResult) -> Iterable[str]: ...
 
     @staticmethod
-    def delete(url: urllib.parse.ParseResult, recursively: bool = False) -> Iterable[str]: ...
+    def delete(url: urllib.parse.ParseResult, recursively: bool = False, dry_run: bool = False) -> Iterable[str]: ...
